summaryrefslogtreecommitdiffstats
path: root/ksirc/toplevel.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
commit9c9412b30c54468adc9e506cc76c5d113fbf5056 (patch)
tree68a0c0d5bc770fc58596b8c5624cdf33d8625027 /ksirc/toplevel.cpp
parent2e53bd0b77676f879fad7baeecea5879bf496a7d (diff)
downloadtdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.tar.gz
tdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'ksirc/toplevel.cpp')
-rw-r--r--ksirc/toplevel.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/ksirc/toplevel.cpp b/ksirc/toplevel.cpp
index 3d502a52..a6b7518d 100644
--- a/ksirc/toplevel.cpp
+++ b/ksirc/toplevel.cpp
@@ -107,7 +107,7 @@ KSircTopLevel::initColors()
}
KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInfo, const char * name)
- : KMainWindow(0, name, 0/*no WDestructiveClose !*/),
+ : TDEMainWindow(0, name, 0/*no WDestructiveClose !*/),
UnicodeMessageReceiver(_proc),
lastBeep( TQTime::currentTime() ),
m_channelInfo(channelInfo)
@@ -115,7 +115,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
{
// prevent us from being quitted when closing a channel-window. Only
// closing the servercontroller shall quit.
// KMainWindow will deref() us in closeEvent
kapp->ref();
@@ -155,7 +155,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
file = new TQPopupMenu(this, TQCString(TQT_TQOBJECT(this)->name()) + "_popup_file");
file->setCheckable(true);
- KAction *act = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT( newWindow() ), actionCollection() );
+ TDEAction *act = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT( newWindow() ), actionCollection() );
act->plug( file );
file->insertItem(i18n("New Ser&ver..."), servercontroller::self(), TQT_SLOT(new_connection()), Key_F2);
file->insertSeparator();
@@ -172,7 +172,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
beepitem = file->insertItem(i18n("N&otify on Change"), this, TQT_SLOT(toggleBeep()), CTRL + Key_P);
file->setItemChecked(beepitem, ksopts->chan(m_channelInfo).beepOnMsg);
- encodingAction = new KSelectAction( i18n( "&Encoding" ), 0, TQT_TQOBJECT(this) );
+ encodingAction = new TDESelectAction( i18n( "&Encoding" ), 0, TQT_TQOBJECT(this) );
connect( encodingAction, TQT_SIGNAL( activated() ), this, TQT_SLOT( setEncoding() ) );
TQStringList encodings = TDEGlobal::charsets()->descriptiveEncodingNames();
@@ -683,7 +683,7 @@ void KSircTopLevel::insertText()
void KSircTopLevel::show()
{
- KMainWindow::show();
+ TDEMainWindow::show();
linee->setFocus();
mainw->scrollToBottom(true);
}
@@ -1199,7 +1199,7 @@ void KSircTopLevel::newWindow()
void KSircTopLevel::closeEvent(TQCloseEvent *e)
{
- KMainWindow::closeEvent( e );
+ TDEMainWindow::closeEvent( e );
e->accept();
//Let's not part the channel till we are acutally delete.
@@ -1654,7 +1654,7 @@ bool KSircTopLevel::event( TQEvent *e)
TQTimer::singleShot(750, this, TQT_SLOT(initColors()));
initColors();
}
- return KMainWindow::event(e);
+ return TDEMainWindow::event(e);
}
void KSircTopLevel::saveCurrLog()
@@ -115,7 +115,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
// prevent us from being quitted when closing a channel-window. Only
// closing the servercontroller shall quit.
- // KMainWindow will deref() us in closeEvent
+ // TDEMainWindow will deref() us in closeEvent
kapp->ref();